pub enum BindError {
InvalidState,
InUse,
NoFreePorts,
Unaddressable,
}Expand description
Error returned by UdpSocket::bind.
Variants
InvalidState
The socket is already bound.
InUse
Another UDP socket holds an identical 4-tuple.
NoFreePorts
No free port in the ephemeral range (only possible with tens of thousands of bound sockets).
Unaddressable
The local and remote addresses belong to different address families, or no local address is available for the given remote.