pub enum RecvError {
InvalidState,
Exhausted,
Truncated,
IcmpError {
error: IcmpError,
remote: IpEndpoint,
},
}Expand description
Error returned by UdpSocket::recv and the peek methods.
Variants
InvalidState
The socket is not bound.
Exhausted
The RX queue is empty.
Truncated
The provided slice is smaller than the payload. (The packet is dropped by
recv_slice, but not by peek_slice.)
IcmpError
An ICMP error message quoting a packet this socket sent has arrived
(reported once, taking it clears it). See
take_icmp_error.
Fields

remote: IpEndpointThe remote endpoint the erring packet was sent to.